/***********************************************************************

GECCO, a platform for command and control gaming

Copyright (C) 2001 Henrik Brnhielm, Andreas Enblom, Niklas
Hallenfur, Karl Hasselstrm, Henrik Hgerstrm, Oskar Linde, Jing Fu
Zi and Jon slund

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or (at
your option) any later version.

This program is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
USA.

***********************************************************************/

package gecco.communication.client;

import gecco.client.*;
import gecco.communication.messages.*;

import java.awt.Color;
import java.awt.Point;
import java.io.*;
import java.util.*;

/**
 *  A class that sends messages to the server
 *
 * @author     Niklas Hallenfur
 * @author     Karl Hasselstrm
 * @author     Henrik Hgerstrm
 * @author     Jon slund
 * @created    June 27, 2001
 */

public class DataOutputExchangeHandler implements Runnable {

    /**
     *  Description of the Field
     */
    private MessageQueue messages_to_send;
    /**
     *  Description of the Field
     */
    private ServerConnection connection;
    /**
     *  Description of the Field
     */
    private ServerAmbassador i_am_working_for;
    /**
     *  Description of the Field
     */
    private boolean die;


    /**
     * @param  q   the queue that will contain the messages to send
     * @param  sc  the connection to send messages to
     * @param  sa  the serverambassador who created this object
     */
    public DataOutputExchangeHandler(MessageQueue q, ServerConnection sc,
            ServerAmbassador sa) {
        messages_to_send = q;
        connection = sc;
        i_am_working_for = sa;
        die = false;
    }


    /**
     *  Used by the ServerAmbassador to add messages to send
     *
     * @param  message  The feature to be added to the MessageToQueue attribute
     */
    public void addMessageToQueue(Message message) {
        synchronized (messages_to_send) {
            messages_to_send.add(message);
            messages_to_send.notifyAll();
        }
    }


    /**
     *  Main processing method for the DataOutputExchangeHandler object
     */
    public void run() {
        while (!die) {
            try {
                Message m = null;
                // Wait until a message is placed in the queue if it's empty!
                synchronized (messages_to_send) {
                    if (messages_to_send.isEmpty()) {
                        messages_to_send.wait();
                    }
                    m = messages_to_send.get();
                }
                // Release sync on message queue, and send message!
                if (m != null) {
                    sendMessage(m);
                    // If we've done something, yield to other threads before continuing!
                    Thread.yield();
                }
            } catch (Exception e) {
		e.printStackTrace(System.out);
                i_am_working_for.connectionLost();
                break;
            }
        }
    }


    /**
     *  called whenever someone wants this thread to die
     */
    public void kill() {
        die = true;
    }


    /**
     *  Called when there are messages to send in the queue. Checks the class of
     *  the message to send, and calls the appropriate method that sends that
     *  kind of message
     *
     * @param  m              Description of Parameter
     * @exception  Exception  Description of Exception
     */
    private void sendMessage(Message m) throws Exception {

	// Send the message.
	m.write(connection.getDataOutputStream());

	// Make sure it's sent right away and not later.
        try {
            connection.getDataOutputStream().flush();
        } catch (Exception e) {
            i_am_working_for.connectionLost();
        }

	// Do anything special for that message.
	if (m instanceof AbortGameMessage) {
	    kill();
	}
    }

}
