/***********************************************************************

GECCO, a platform for command and control gaming

Copyright (C) 2001 Henrik Brnhielm, Andreas Enblom, Niklas
Hallenfur, Karl Hasselstrm, Henrik Hgerstrm, Oskar Linde, Jing Fu
Zi and Jon slund

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or (at
your option) any later version.

This program is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
USA.

***********************************************************************/

package gecco.communication.messages;

import java.io.*;

/**
 *  This message is put in the send queue on the server part of the
 *  communication when a unit property is updated.
 *
 * @author     Karl Hasselstrm
 * @created July 25, 2001
 */
public class UnitPropertyUpdateMessage extends Message {
    /**
     *  Description of the Field
     */
    public int handle;
    /**
     *  Description of the Field
     */
    public String key;
    /**
     *  Description of the Field
     */
    public String newValue;


    /**
     *  Constructor for the UnitPropertyChangedMessage object
     *
     * @param  handle    Description of Parameter
     * @param  key       Description of Parameter
     * @param  newValue  Description of Parameter
     */
    public UnitPropertyUpdateMessage(int handle, String key, String newValue) {
        this.handle = handle;
        this.key = key;
        this.newValue = newValue;
    }



    /**
     *  This method writes the message to the given
     *  <code>DataOutput</code>.
     *
     * @param out The output stream.
     * @exception  IOException  In case something goes wrong.
     */
    public void write(DataOutput out) throws IOException {

        out.writeInt(MessageType.UnitPropertyUpdate);

        out.writeInt(handle);
        out.writeUTF(key);
        out.writeUTF(newValue);
    }


    /**
     *  This factory method reads a message of this type without an
     *  initial ID from the input stream, and returns a
     *  <code>Message</code> object.
     *
     * @param  in  The input stream.
     * @return     An instance of <code>Message</code>.
     */
    public static Message read(DataInput in) throws IOException {

	int handle = in.readInt();
	String key = in.readUTF();
	String value = in.readUTF();

	return new UnitPropertyUpdateMessage(handle, key, value);
    }

}
