/***********************************************************************

GECCO, a platform for command and control gaming

Copyright (C) 2001 Henrik Brnhielm, Andreas Enblom, Niklas
Hallenfur, Karl Hasselstrm, Henrik Hgerstrm, Oskar Linde, Jing Fu
Zi and Jon slund

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or (at
your option) any later version.

This program is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
USA.

***********************************************************************/

package gecco.server.visibility;

import gecco.server.actionprocessor.ActionProcessor;
import gecco.server.automaton.AutomatonMap;
import gecco.server.core.*;
import gecco.server.qmanager.QManager;
import gecco.server.unitmanager.UnitManager;

import java.awt.Color;
import java.util.*;

/**
 *  Description of the Class
 *
 * @author     Karl Hasselstrm
 * @author     Henrik Hgerstrm
 * @created    June 27, 2001
 */
public interface VisibilityInfo {

    /**
     *  Determines if at least one unit of which the given role is an
     *  observer can see the given position.
     *
     * @param  role  The role.
     * @param  x     The X coordinate of the position.
     * @param  y     The Y coordinate of the position.
     * @return       true if the position can be seen, false otherwise.
     */
    public boolean canSeePosition(String role, double x, double y);
    

    /**
     *  Determines if at least one unit of which the given role is an
     *  observer can see the given automaton, not counting the given
     *  unit. You can set excludeUnit to null if you don't want to
     *  exclude any unit.
     *
     * @param  role         The role.
     * @param  x            The X coordinate of the automaton.
     * @param  y            The Y coordinate of the automaton.
     * @param  excludeUnit  Don't count this unit (may be null).
     * @return true if the automaton can be seen, false otherwise.
     */
    public boolean canSeeAutomaton(String role, int x, int y, Unit excludeUnit);


    /**
     *  Determines if at least one unit of which the given role is an
     *  observer can see the given unit. If excludeUnit is non-null,
     *  that unit will not be counted.
     *
     * @param  role         The role.
     * @param  unit         The unit to be spotted.
     * @param  excludeUnit  Don't count this unit (may be null).
     * @return true if the unit can be seen, false otherwise.
     */
    public boolean canSeeUnit(String role, Unit unit, Unit excludeUnit);

}
